@@ -11,7 +11,7 @@
 #include <kdev-pg-list.h>
 
 
-# 45 "/build/kdevelop-php/src/kdev-php-23.08.5/parser/php.g" 1
+# 45 "/build/kdevelop-php/src/kdev-php-24.02.0/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
@@ -26,7 +26,7 @@ namespace Php
 {
 
 
-# 79 "/build/kdevelop-php/src/kdev-php-23.08.5/parser/php.g" 1
+# 79 "/build/kdevelop-php/src/kdev-php-24.02.0/parser/php.g" 1
 
 class Lexer;
 
@@ -188,51 +188,56 @@ struct KDEVPHPPARSER_EXPORT AstNode
         ParameterKind = 1091,
         ParameterListKind = 1092,
         ParameterTypeKind = 1093,
-        PostprefixOperatorKind = 1094,
-        PrintExpressionKind = 1095,
-        PropertyTypeKind = 1096,
-        PropertyTypeHintKind = 1097,
-        RelationalExpressionKind = 1098,
-        RelationalExpressionRestKind = 1099,
-        ReservedNonModifierIdentifierKind = 1100,
-        ReservedNonModifiersKind = 1101,
-        ReturnTypeKind = 1102,
-        ScalarKind = 1103,
-        SemiReservedKind = 1104,
-        SemiReservedIdentifierKind = 1105,
-        SemicolonOrCloseTagKind = 1106,
-        ShiftExpressionKind = 1107,
-        ShiftExpressionRestKind = 1108,
-        StartKind = 1109,
-        StatementKind = 1110,
-        StaticArrayPairValueKind = 1111,
-        StaticMemberKind = 1112,
-        StaticPropertyKind = 1113,
-        StaticScalarKind = 1114,
-        StaticVarKind = 1115,
-        StringIndexSpecifierKind = 1116,
-        SwitchCaseListKind = 1117,
-        TopStatementKind = 1118,
-        TraitAliasDeclarationKind = 1119,
-        TraitAliasIdentifierKind = 1120,
-        TraitAliasStatementKind = 1121,
-        TraitDeclarationStatementKind = 1122,
-        TraitVisibilityModifiersKind = 1123,
-        UnaryExpressionKind = 1124,
-        UnaryExpressionNotPlusminusKind = 1125,
-        UseNamespaceOrUseGroupedNamespaceKind = 1126,
-        UseStatementKind = 1127,
-        VarExpressionKind = 1128,
-        VarExpressionArrayKind = 1129,
-        VarExpressionNewObjectKind = 1130,
-        VarExpressionNormalKind = 1131,
-        VariableKind = 1132,
-        VariableIdentifierKind = 1133,
-        VariableNameKind = 1134,
-        VariableObjectPropertyKind = 1135,
-        VariablePropertyKind = 1136,
-        VariableWithoutObjectsKind = 1137,
-        WhileStatementKind = 1138,
+        ParameterTypeHintKind = 1094,
+        PostprefixOperatorKind = 1095,
+        PrintExpressionKind = 1096,
+        PropertyTypeKind = 1097,
+        PropertyTypeHintKind = 1098,
+        RelationalExpressionKind = 1099,
+        RelationalExpressionRestKind = 1100,
+        ReservedNonModifierIdentifierKind = 1101,
+        ReservedNonModifiersKind = 1102,
+        ReturnTypeKind = 1103,
+        ReturnTypeHintKind = 1104,
+        ScalarKind = 1105,
+        SemiReservedKind = 1106,
+        SemiReservedIdentifierKind = 1107,
+        SemicolonOrCloseTagKind = 1108,
+        ShiftExpressionKind = 1109,
+        ShiftExpressionRestKind = 1110,
+        StartKind = 1111,
+        StatementKind = 1112,
+        StaticArrayPairValueKind = 1113,
+        StaticMemberKind = 1114,
+        StaticPropertyKind = 1115,
+        StaticScalarKind = 1116,
+        StaticVarKind = 1117,
+        StringIndexSpecifierKind = 1118,
+        SwitchCaseListKind = 1119,
+        TopStatementKind = 1120,
+        TraitAliasDeclarationKind = 1121,
+        TraitAliasIdentifierKind = 1122,
+        TraitAliasStatementKind = 1123,
+        TraitDeclarationStatementKind = 1124,
+        TraitVisibilityModifiersKind = 1125,
+        UnaryExpressionKind = 1126,
+        UnaryExpressionNotPlusminusKind = 1127,
+        UnionParameterTypeKind = 1128,
+        UnionPropertyTypeKind = 1129,
+        UnionReturnTypeKind = 1130,
+        UseNamespaceOrUseGroupedNamespaceKind = 1131,
+        UseStatementKind = 1132,
+        VarExpressionKind = 1133,
+        VarExpressionArrayKind = 1134,
+        VarExpressionNewObjectKind = 1135,
+        VarExpressionNormalKind = 1136,
+        VariableKind = 1137,
+        VariableIdentifierKind = 1138,
+        VariableNameKind = 1139,
+        VariableObjectPropertyKind = 1140,
+        VariablePropertyKind = 1141,
+        VariableWithoutObjectsKind = 1142,
+        WhileStatementKind = 1143,
         AST_NODE_KIND_COUNT
     };
 
@@ -240,7 +245,7 @@ struct KDEVPHPPARSER_EXPORT AstNode
     qint64 startToken;
     qint64 endToken;
 
-# 141 "/build/kdevelop-php/src/kdev-php-23.08.5/parser/php.g" 1
+# 141 "/build/kdevelop-php/src/kdev-php-24.02.0/parser/php.g" 1
 
     KDevelop::DUContext* ducontext;
 
@@ -757,7 +762,6 @@ struct KDEVPHPPARSER_EXPORT GenericTypeHintAst: public AstNode
 
     NamespacedIdentifierAst *genericType;
     qint64 arrayType;
-    qint64 callableType;
 };
 
 struct KDEVPHPPARSER_EXPORT GlobalVarAst: public AstNode
@@ -995,8 +999,17 @@ struct KDEVPHPPARSER_EXPORT ParameterTypeAst: public AstNode
 {
     enum { KIND = ParameterTypeKind };
 
+    UnionParameterTypeAst *typehint;
+};
+
+struct KDEVPHPPARSER_EXPORT ParameterTypeHintAst: public AstNode
+{
+    enum { KIND = ParameterTypeHintKind };
+
+    int voidType;
     qint64 isNullable;
-    GenericTypeHintAst *typehint;
+    GenericTypeHintAst *genericType;
+    qint64 callableType;
 };
 
 struct KDEVPHPPARSER_EXPORT PostprefixOperatorAst: public AstNode
@@ -1018,8 +1031,7 @@ struct KDEVPHPPARSER_EXPORT PropertyTypeAst: public AstNode
 {
     enum { KIND = PropertyTypeKind };
 
-    qint64 isNullable;
-    PropertyTypeHintAst *typehint;
+    UnionPropertyTypeAst *typehint;
 };
 
 struct KDEVPHPPARSER_EXPORT PropertyTypeHintAst: public AstNode
@@ -1027,8 +1039,9 @@ struct KDEVPHPPARSER_EXPORT PropertyTypeHintAst: public AstNode
     enum { KIND = PropertyTypeHintKind };
 
     int callableType;
-    NamespacedIdentifierAst *genericType;
-    qint64 arrayType;
+    int voidType;
+    qint64 isNullable;
+    GenericTypeHintAst *genericType;
 };
 
 struct KDEVPHPPARSER_EXPORT RelationalExpressionAst: public AstNode
@@ -1064,8 +1077,16 @@ struct KDEVPHPPARSER_EXPORT ReturnTypeAst: public AstNode
 {
     enum { KIND = ReturnTypeKind };
 
+    UnionReturnTypeAst *typehint;
+};
+
+struct KDEVPHPPARSER_EXPORT ReturnTypeHintAst: public AstNode
+{
+    enum { KIND = ReturnTypeHintKind };
+
     qint64 isNullable;
-    GenericTypeHintAst *typehint;
+    GenericTypeHintAst *genericType;
+    qint64 callableType;
     qint64 voidType;
 };
 
@@ -1295,6 +1316,27 @@ struct KDEVPHPPARSER_EXPORT UnaryExpressionNotPlusminusAst: public AstNode
     const KDevPG::ListNode<PostprefixOperatorAst *> *postfixOperatorSequence;
 };
 
+struct KDEVPHPPARSER_EXPORT UnionParameterTypeAst: public AstNode
+{
+    enum { KIND = UnionParameterTypeKind };
+
+    const KDevPG::ListNode<ParameterTypeHintAst *> *unionTypeSequence;
+};
+
+struct KDEVPHPPARSER_EXPORT UnionPropertyTypeAst: public AstNode
+{
+    enum { KIND = UnionPropertyTypeKind };
+
+    const KDevPG::ListNode<PropertyTypeHintAst *> *unionTypeSequence;
+};
+
+struct KDEVPHPPARSER_EXPORT UnionReturnTypeAst: public AstNode
+{
+    enum { KIND = UnionReturnTypeKind };
+
+    const KDevPG::ListNode<ReturnTypeHintAst *> *unionTypeSequence;
+};
+
 struct KDEVPHPPARSER_EXPORT UseNamespaceOrUseGroupedNamespaceAst: public AstNode
 {
     enum { KIND = UseNamespaceOrUseGroupedNamespaceKind };
